@@ -1,6 +1,7 @@
 import os
 import pprint
 import datetime
+import time
 from .handlers import html_minify, css_minify, js_minify, sass_minify, png_minify, jpeg_minify, svg_minify
 from .files import path_is_in_path, generate_file_list, determine_file_extension
 from .time import human_delta
@@ -8,6 +9,8 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+now = datetime.datetime.now()
+
 
 class Processor:
     def __init__(self, settings: dict):
@@ -54,21 +57,25 @@ class Processor:
         if self.verbose:
             logger.info(f"Processing '{input_path}' to '{output_path}'")
         if not input_path:
-            logger.warning(f"No input path specified")
+            logger.warning("No input path specified")
             return False
         if not output_path:
-            logger.warning(f"No output path specified")
+            logger.warning("No output path specified")
             return False
+        input_mtime = now
         if os.path.isfile(output_path):
             if not self.overwrite:
-                logger.warning(f"Trying to overwrite without overwrite enabled")
+                logger.warning(f"Trying to overwrite '{output_path}' without overwrite enabled")
                 return False
             if self.on_change:
                 input_mtime = os.path.getmtime(input_path)
                 output_mtime = os.path.getmtime(output_path)
-                if input_mtime <= output_mtime:
+                if input_mtime == output_mtime:
                     if self.verbose:
-                        logger.info(f"File not changed, skipping")
+                        logger.info("File '{output_path}' not changed, skipping")
+                    return True
+                elif input_mtime > output_mtime:
+                    logger.warning(f"Destination file '{output_path}' newer than input, skipping")
                     return True
         else:
             output_dir = os.path.dirname(output_path)
@@ -113,6 +120,8 @@ class Processor:
                 if written != len(processed_content):
                     logger.warning(f"Partially written output ({written} of {len(processed_content)} bytes).")
                     return False
+                input_mtime_mod = time.mktime(input_mtime.timetuple())
+                os.utime(output_path, (input_mtime_mod, input_mtime_mod))
         except Exception as err:
             logger.warning(f"Could not write data to output file '{output_path}': {err}.")
             return False
